Documentation
¶
Overview ¶
Package alligopher is a lexer and parser library for Go.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Lexer lexer
Functions ¶
This section is empty.
Types ¶
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
type TokenTypes ¶
TokenTypes is ...
func (TokenTypes) Validate ¶
func (t TokenTypes) Validate()
Validate validates if the token types keys are all uppercase.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.